@@ -11,11 +11,12 @@ from .Volume import Volume
 
 
 class Manager(BaseAPI):
+
     def __init__(self, auth_token, consumer_token=None):
         super(Manager, self).__init__(auth_token, consumer_token)
 
     def call_api(self, method, type='GET', params=None):
-        return super(Manager, self).call_api(method, type, params)  # pragma: no cover
+        return super(Manager, self).call_api(method, type, params)
 
     def get_user(self):
         return self.call_api("user")
@@ -70,27 +71,50 @@ class Manager(BaseAPI):
             devices.append(device)
         return devices
 
-    def create_device(self, project_id, hostname, plan, facility,
-                      operating_system, billing_cycle='hourly', userdata='',
-                      locked=False, tags={}, features={}, ipxe_script_url='', always_pxe=False):
+    def create_device(self,
+                      project_id,
+                      hostname,
+                      plan,
+                      facility,
+                      operating_system,
+                      always_pxe=False,
+                      billing_cycle='hourly',
+                      features={},
+                      ipxe_script_url='',
+                      locked=False,
+                      project_ssh_keys=[],
+                      public_ipv4_subnet_size=31,
+                      spot_instance=False,
+                      spot_price_max=-1,
+                      tags={},
+                      termination_time=None,
+                      user_ssh_keys=[],
+                      userdata=''):
 
         params = {
-            'hostname': hostname,
-            'project_id': project_id,
-            'plan': plan,
-            'facility': facility,
-            'operating_system': operating_system,
             'billing_cycle': billing_cycle,
-            'userdata': userdata,
-            'locked': locked,
+            'facility': facility,
             'features': features,
+            'hostname': hostname,
+            'locked': locked,
+            'operating_system': operating_system,
+            'plan': plan,
+            'project_id': project_id,
+            'public_ipv4_subnet_size': public_ipv4_subnet_size,
+            'project_ssh_keys': project_ssh_keys,
             'tags': tags,
+            'user_ssh_keys': user_ssh_keys,
+            'userdata': userdata,
         }
 
         if ipxe_script_url != '':
-            params['operating_system'] = 'custom_ipxe'
-            params['ipxe_script_url'] = ipxe_script_url
             params['always_pxe'] = always_pxe
+            params['ipxe_script_url'] = ipxe_script_url
+            params['operating_system'] = 'custom_ipxe'
+        if spot_instance:
+            params['spot_instance'] = spot_instance
+            params['spot_price_max'] = spot_price_max
+            params['termination_time'] = termination_time
         data = self.call_api('projects/%s/devices' % project_id, type='POST', params=params)
         return Device(data, self)
 
@@ -150,13 +174,7 @@ class Manager(BaseAPI):
     def validate_capacity(self, servers):
         params = {'servers': []}
         for server in servers:
-            params['servers'].append(
-                {
-                    'facility': server[0],
-                    'plan': server[1],
-                    'quantity': server[2]
-                }
-            )
+            params['servers'].append({'facility': server[0], 'plan': server[1], 'quantity': server[2]})
 
         try:
             self.call_api('/capacity', 'POST', params)
@@ -166,3 +184,7 @@ class Manager(BaseAPI):
                 return False
             else:
                 raise e
+
+    def get_spot_market_prices(self, params={}):
+        data = self.call_api('/market/spot/prices', params=params)
+        return data["spot_market_prices"]
