@@ -6,6 +6,7 @@ import requests
 
 class Error(Exception):  # pragma: no cover
     """Base exception class for this module"""
+
     def __init__(self, msg, cause=None):
         super(Error, self).__init__(msg)
         self._cause = cause
@@ -31,73 +32,69 @@ class BaseAPI(object):
         self.end_point = 'api.packet.net'
         self._log = logging.getLogger(__name__)
 
-    def call_api(self, method, type='GET', params=None):  # pragma: no cover
+    def call_api(self, method, type='GET', params=None):  # noqa
         if params is None:
             params = {}
 
         url = 'https://' + self.end_point + '/' + method
 
-        headers = {'X-Auth-Token': self.auth_token,
-                   'X-Consumer-Token': self.consumer_token,
-                   'Content-Type': 'application/json'}
+        headers = {
+            'X-Auth-Token': self.auth_token,
+            'X-Consumer-Token': self.consumer_token,
+            'Content-Type': 'application/json'
+        }
 
         # remove token from log
         headers_str = str(headers).replace(self.auth_token.strip(), 'TOKEN')
-        self._log.debug('%s %s %s %s' %
-                        (type, url, params, headers_str))
+        self._log.debug('%s %s %s %s' % (type, url, params, headers_str))
         try:
             if type == 'GET':
                 url = url + '%s' % self._parse_params(params)
                 resp = requests.get(url, headers=headers)
             elif type == 'POST':
-                resp = requests.post(url, headers=headers,
-                                     data=json.dumps(params))
+                resp = requests.post(url, headers=headers, data=json.dumps(params))
             elif type == 'DELETE':
                 resp = requests.delete(url, headers=headers)
             elif type == 'PATCH':
-                resp = requests.patch(url, headers=headers,
-                                      data=json.dumps(params))
-            else:
-                raise Error(
-                    'method type not recognized as one of GET, POST, DELETE or PATCH: %s' % type
-                )
-        except requests.exceptions.RequestException as e:
+                resp = requests.patch(url, headers=headers, data=json.dumps(params))
+            else:  # pragma: no cover
+                raise Error('method type not recognized as one of GET, POST, DELETE or PATCH: %s' % type)
+        except requests.exceptions.RequestException as e:  # pragma: no cover
             raise Error('Communcations error: %s' % str(e), e)
+
         if not resp.content:
             data = None
         elif resp.headers.get("content-type", "").startswith("application/json"):
             try:
                 data = resp.json()
-            except ValueError as e:
-                raise JSONReadError(
-                    'Read failed: %s' % e.message, e
-                )
+            except ValueError as e:  # pragma: no cover
+                raise JSONReadError('Read failed: %s' % e.message, e)
         else:
-            data = resp.content
+            data = resp.content  # pragma: no cover
 
-        if not resp.ok:
+        if not resp.ok:  # pragma: no cover
             msg = data
             if not data:
                 msg = "(empty response)"
             elif 'errors' in data:
                 msg = ', '.join(data['errors'])
-            raise Error(
-                'Error {0}: {1}'.format(resp.status_code, msg)
-            )
+            raise Error('Error {0}: {1}'.format(resp.status_code, msg))
+
         try:
             resp.raise_for_status()
-        except requests.HTTPError as e:
-            raise Error('Error {0}: {1}'.format(resp.status_code,
-                                                resp.reason), e)
+        except requests.HTTPError as e:  # pragma: no cover
+            raise Error('Error {0}: {1}'.format(resp.status_code, resp.reason), e)
+
         self.meta = None
         try:
             if data and data['meta']:
                 self.meta = data['meta']
         except (KeyError, IndexError):
             pass
+
         return data
 
-    def _parse_params(self, params):  # pragma: no cover
+    def _parse_params(self, params):
         vals = list()
         for k, v in params.items():
             vals.append(str("%s=%s" % (k, v)))
